@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 2013-2015.
+ * Copyright (c) Tony Bybell 2013-2017.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -816,7 +816,8 @@ switch (cb_type)
 		break;
 
     	case FSDB_TREE_CBT_END_TREE:
-		/* fprintf(stderr, "End Tree:\n"); */
+		strcpy(bf, "End Tree:");
+		cb(bf);
 		break;
 
 	case FSDB_TREE_CBT_STRUCT_BEGIN:
