@@ -260,6 +260,8 @@ unsigned char extload_vt_prev;
 unsigned char extload_vd_prev;
 int f_name_build_buf_len;
 char *f_name_build_buf;
+unsigned int extload_max_tree;
+unsigned int extload_curr_tree;
 
 
 /*
@@ -640,6 +642,7 @@ GtkWidget *sst_signal_popup_menu; /* from menu.c */
  * mouseover.c
  */
 char disable_mouseover; /* from mouseover.c 271 */
+char clipboard_mouseover; /* from mouseover.c */
 GtkWidget *mouseover_mouseover_c_1; /* from mouseover.c 272 */
 GtkWidget *mo_area_mouseover_c_1; /* from mouseover.c 273 */
 GdkDrawable *mo_pixmap_mouseover_c_1; /* from mouseover.c 274 */
