@@ -119,6 +119,7 @@ GLOBALS->highlight_wavewindow = g_old->highlight_wavewindow;
 GLOBALS->fill_waveform = g_old->fill_waveform;
 GLOBALS->use_standard_trace_select = g_old->use_standard_trace_select;
 GLOBALS->disable_mouseover = g_old->disable_mouseover;
+GLOBALS->clipboard_mouseover = g_old->clipboard_mouseover;
 GLOBALS->keep_xz_colors = g_old->keep_xz_colors;
 GLOBALS->zoom_pow10_snap = g_old->zoom_pow10_snap;
 GLOBALS->zoom_dyn = g_old->zoom_dyn;
@@ -610,6 +611,7 @@ if(!GLOBALS)
 	GLOBALS->constant_marker_update = old_g->constant_marker_update;
 	GLOBALS->convert_to_reals = old_g->convert_to_reals;
 	GLOBALS->disable_mouseover = old_g->disable_mouseover;
+	GLOBALS->clipboard_mouseover = old_g->clipboard_mouseover;
 	GLOBALS->keep_xz_colors = old_g->keep_xz_colors;
 	GLOBALS->disable_tooltips = old_g->disable_tooltips;
 	GLOBALS->do_initial_zoom_fit = old_g->do_initial_zoom_fit;
@@ -691,6 +693,9 @@ if(!GLOBALS)
 	GLOBALS->make_vcd_save_file = old_g->make_vcd_save_file;
 	GLOBALS->strace_repeat_count = old_g->strace_repeat_count;
 
+	GLOBALS->extload_max_tree = old_g->extload_max_tree;
+	GLOBALS->do_hier_compress = old_g->do_hier_compress;
+
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->editor_name, &old_g->editor_name);
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_logfile, &old_g->fontname_logfile);
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_signals, &old_g->fontname_signals);
