@@ -171,6 +171,13 @@ GLOBALS->disable_mouseover=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_clipboard_mouseover(char *str)
+{
+DEBUG(printf("f_clipboard_mouseover(\"%s\")\n",str));
+GLOBALS->clipboard_mouseover=atoi_64(str)?1:0;
+return(0);
+}
+
 int f_disable_tooltips(char *str)
 {
 DEBUG(printf("f_disable_tooltips(\"%s\")\n",str));
@@ -451,6 +458,16 @@ GLOBALS->lxt_clock_compress_to_z=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_max_fsdb_trees(char *str)
+{
+int val;
+DEBUG(printf("f_max_fsdb_trees(\"%s\")\n",str));
+val=atoi_64(str);
+GLOBALS->extload_max_tree=(val<0)?0:val;
+return(0);
+}
+
+
 int f_page_divisor(char *str)
 {
 DEBUG(printf("f_page_divisor(\"%s\")\n",str));
@@ -822,6 +839,7 @@ static struct rc_entry rcitems[]=
 { "autocoalesce", f_autocoalesce },
 { "autocoalesce_reversal", f_autocoalesce_reversal },
 { "autoname_bundles", f_autoname_bundles },
+{ "clipboard_mouseover", f_clipboard_mouseover },
 { "color_0", f_color_0 },
 { "color_1", f_color_1 },
 { "color_1fill", f_color_1fill },
@@ -899,6 +917,7 @@ static struct rc_entry rcitems[]=
 { "keep_xz_colors", f_keep_xz_colors },
 { "left_justify_sigs", f_left_justify_sigs },
 { "lxt_clock_compress_to_z", f_lxt_clock_compress_to_z },
+{ "max_fsdb_trees", f_max_fsdb_trees },
 { "page_divisor", f_page_divisor },
 { "ps_maxveclen", f_ps_maxveclen },
 { "ruler_origin", f_ruler_origin },
